@@ -66,7 +66,7 @@
 #include <scsi/scsi_ioctl.h>
 
 /* Global Variables */
-const char *version = "2.0.3"; /* program version */
+const char *version = VERSION; /* program version */
 int a_option = 0; /* command flags and arguments */
 int c_option = 0;
 int d_option = 0;
@@ -104,6 +104,7 @@ static void usage()
 "Eject version %s by Jeff Tranter (tranter@pobox.com)\n"
 "Usage:\n"
 "  eject -h                             -- display command usage and exit\n"
+"  eject -V                             -- display program version and exit\n"
 "  eject [-vnrsfq] [<name>]             -- eject device\n"
 "  eject [-vn] -d                       -- display default device\n"
 "  eject [-vn] -a on|off|1|0 [<name>]   -- turn auto-eject feature on or off\n"
@@ -121,7 +122,7 @@ static void usage()
 "  -h --help   -v --verbose      -d --default\n"
 "  -a --auto   -c --changerslot  -t --trayclose\n"
 "  -r --cdrom  -s --scsi         -f --floppy\n"
-"  -q --tape   -n --noop\n"
+"  -q --tape   -n --noop         -V --version\n"
 #endif /* GETOPTLONG */
 "Parameter <name> can be a device file or a mount point.\n"
 "If omitted, name defaults to `%s'.\n"
@@ -134,7 +135,7 @@ static void usage()
 /* Handle command line options. */
 static void parse_args(int argc, char **argv, char **device)
 {
-  const char *flags = "a:c:dfhnqrstv";
+  const char *flags = "a:c:dfhnqrstvV";
 #ifdef GETOPTLONG
   static struct option long_options[] =
   {
@@ -149,6 +150,7 @@ static void parse_args(int argc, char **argv, char **device)
     {"scsi",        no_argument,       NULL, 's'},
     {"floppy",      no_argument,       NULL, 'f'},
     {"tape",        no_argument,       NULL, 'q'},
+    {"version",     no_argument,       NULL, 'V'},
     {0, 0, 0, 0}
   };
   int option_index;
@@ -217,6 +219,10 @@ static void parse_args(int argc, char **argv, char **device)
     case 'v':
       v_option = 1;
       break;
+    case 'V':
+		printf("eject version %s by Jeff Tranter (tranter@pobox.com)\n", version);
+		exit(0);
+      break;
     case '?':
       exit(1);
       break;
@@ -257,7 +263,6 @@ Given name, such as foo, see if any of the following exist:
 - /dev/cdroms/foo0
 - /dev/dsk/foo
 - /dev/rdsk/foo
-- /mnt/foo
 - ./foo
 If found, return the full path. If not found, return 0.
 Returns pointer to dynamically allocated string.
@@ -266,7 +271,7 @@ static char *FindDevice(const char *name)
 {
   char *buf;
 
-  buf = (char *) malloc(strlen(name)+9);
+  buf = (char *) malloc(strlen(name)+14); /* to allow for "/dev/cdroms/ + "0" + null */
 
   if ((name[0] == '.') || (name[0] == '/')) {
     strcpy(buf, name);
@@ -697,6 +702,7 @@ int main(int argc, char **argv)
   int mounted = 0;   /* true if device is mounted */
   int mountable = 0; /* true if device is in /etc/fstab */
   char *pattern;     /* regex for device if multiple partitions */
+  int ld = 6;        /* symbolic link max depth */
 
   /* program name is global variable used by other procedures */
   programName = strdup(argv[0]);
@@ -735,14 +741,19 @@ int main(int argc, char **argv)
     printf("%s: expanded name is `%s'\n", programName, fullName);
 
   /* check for a symbolic link */
-  linkName = SymLink(fullName);
-  if (linkName != 0) {
+    while ((linkName = SymLink(fullName)) && (ld > 0)) {
     if (v_option)
       printf("%s: `%s' is a link to `%s'\n", programName, fullName, linkName);
     free(fullName);
     fullName = strdup(linkName);
     free(linkName);
     linkName = 0;
+    ld--;
+    }
+   /* handle max depth exceeded option */
+   if (ld <= 0) {
+     printf("%s: maximum symbolic link depth exceeded: `%s'\n", programName, fullName);
+     exit(1);
   }
 
   /* if mount point, get device name */
